@@ -433,8 +433,11 @@ impl Session {
         // FIXME: we don't know our section PK. We must supply a pk for now we do a random one...
         let random_section_pk = threshold_crypto::SecretKey::random().public_key();
 
-        let msg = SectionInfoMsg::GetSectionQuery(client_pk)
-            .serialize(dest_section_name, random_section_pk)?;
+        let msg = SectionInfoMsg::GetSectionQuery {
+            public_key: client_pk,
+            is_node: false,
+        }
+        .serialize(dest_section_name, random_section_pk)?;
 
         self.endpoint()?
             .send_message(msg, bootstrapped_peer)
@@ -443,9 +446,9 @@ impl Session {
         Ok(())
     }
 
-    pub(crate) fn disconnect_from_peers(&self, peers: Vec<SocketAddr>) -> Result<(), Error> {
+    pub(crate) async fn disconnect_from_peers(&self, peers: Vec<SocketAddr>) -> Result<(), Error> {
         for elder in peers {
-            self.endpoint()?.disconnect_from(&elder)?;
+            self.endpoint()?.disconnect_from(&elder).await?;
         }
 
         Ok(())
